@@ -423,19 +423,19 @@ class ComicDb():
 # fetch earlier
 	def fetch_earlier(self, comic, earliest):
 		print "fetch before, " + comic + " earliest"
-		if comic == "cyanide" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari":
+		if comic == "cyanide" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari" or comic == "wulff_new":
 			print "getting get_prev_id..."
 			comicid = self.get_prev_id(comic,earliest)
 			if not comicid:
 				print "already at first comic"
 				return
 			print "got " + comicid + " as the one before current..."
-                elif comic == "wulff_new":
+		#elif :
 			# date id.
-			dt = string.split(earliest, "/")
-			d = datetime.date(int(dt[0]),int(dt[1]),int(dt[2]))
-			earlier = d - datetime.timedelta( 1 )
-			comicid = earlier.strftime("%Y/%m/%d")
+		#	dt = string.split(earliest, "/")
+		#	d = datetime.date(int(dt[0]),int(dt[1]),int(dt[2]))
+		#	earlier = d - datetime.timedelta( 1 )
+		#	comicid = earlier.strftime("%Y/%m/%d")
 		elif len(str(earliest)) == 10:
 			# date id.
 			dt = string.split(earliest, "-")
@@ -470,17 +470,11 @@ class ComicDb():
 
 
 	def fetch_newer(self, comic, newest):
-		if comic == "cyanide" or comic == "wulff" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari":
+		if comic == "cyanide" or comic == "wulff" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari" or comic == "wulff_new":
 			comicid = self.get_next_id(comic,newest)
 			if not comicid:
 				print "already at last comic"
 				return
-                elif comic == "wulff_new":
-			# date id.
-			dt = string.split(newest, "/")
-			d = datetime.date(int(dt[0]),int(dt[1]),int(dt[2]))
-			earlier = d + datetime.timedelta( 1 )
-			comicid = earlier.strftime("%Y/%m/%d")
 		elif len(newest) == 10:
 			# date id.
 			dt = string.split(newest, "-")
@@ -623,8 +617,8 @@ class ComicDb():
 				else:
 					print "got next: " + splt[0]
 					return splt[0]	
-		if comic == 'wulff':
-			link = "http://wulffmorgenthaler.com/default.aspx?id=" + number
+		elif comic == 'wulff_new':
+			link = "http://wulffmorgenthaler.com/" + number
 			print "link: " + link
 			try:
 				f = urllib2.urlopen(link)
@@ -637,23 +631,13 @@ class ComicDb():
 			else:
 				s = f.read()
 				f.close()
-				# title:
-				splt = string.split(s, '<a href="/default.aspx?id=', 1)
-				if not splt[1][36:69] == '" id="ctl00_content_Strip1_aPrev"':
-					print "no previous found"
-					if not splt[1][36:69] == '" id="ctl00_content_Strip1_aNext"':
-						print "no next found!"
-						return False
-				else:
-					splt = string.split(splt[1], '<a href="/default.aspx?id=', 1)
-				if len(splt) < 2:
-					print "no next found! At newest comic!"
-					return False
-				if not splt[1][36:69] == '" id="ctl00_content_Strip1_aNext"':
-					print "no next found!"
+				# title: 2011/04/18
+				splt = string.split(s, 'class="next"><a href="/', 1)
+				if not len(splt) == 2:
+					print "no next found"
 					return False
 				else:
-					return splt[1][:36]
+					return splt[1][:10]
 		elif comic[-9:] == "comicscom":
 			link = comics[comic]['link'] + str(number) + "/"
 			print "link: " + link
@@ -761,8 +745,8 @@ class ComicDb():
 				else:
 					print "got previous: " + splt[0]
 					return splt[0]	
-		elif comic == 'wulff':
-			link = "http://wulffmorgenthaler.com/default.aspx?id=" + number
+		elif comic == 'wulff_new':
+			link = "http://wulffmorgenthaler.com/" + number
 			print "link: " + link
 			try:
 				f = urllib2.urlopen(link)
@@ -775,15 +759,13 @@ class ComicDb():
 			else:
 				s = f.read()
 				f.close()
-				# title:
-				splt = string.split(s, '<a href="/default.aspx?id=', 1)
-				if not splt[1][36:69] == '" id="ctl00_content_Strip1_aPrev"':
-					print splt[1][36:69]
-					print splt[1][:36]
+				# title: 2011/04/18
+				splt = string.split(s, 'class="prev"><a href="/', 1)
+				if not len(splt) == 2:
 					print "no previous found"
 					return False
 				else:
-					return splt[1][:36]
+					return splt[1][:10]
 		elif comic[-9:] == "comicscom":
 			print "fetch prev, still in function..."
 			link = comics[comic]['link'] + str(number) + "/"
